pymodaq_plugins_montana
#######################

.. the following must be adapted to your developed package, links to pypi, github  description...

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_montana.svg
   :target: https://pypi.org/project/pymodaq_plugins_montana/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/PyMoDAQ/pymodaq_plugins_montana/workflows/Upload%20Python%20Package/badge.svg
   :target: https://github.com/PyMoDAQ/pymodaq_plugins_montana
   :alt: Publication Status

.. image:: https://github.com/PyMoDAQ/pymodaq_plugins_montana/actions/workflows/Test.yml/badge.svg
    :target: https://github.com/PyMoDAQ/pymodaq_plugins_montana/actions/workflows/Test.yml


Authors
=======

* Sébastien J. Weber (sebastien.weber@cemes.fr)


Instruments
===========

Below is the list of instruments included in this plugin

Actuators
+++++++++

* **CryoTemperature**: control the User1 (could be the ATSM) temperature set point
* **Rook**: control of the Rook nano-positioner

Viewer0D
++++++++

* **CryoInfo**: Get the Cryostat Temperature and Pressure


Installation instructions
=========================

* PyMoDAQ’s >= 5.
* Operating system’s version: any
* Will work only if the IP address of your instrument is reachable on your network
